@@ -5,7 +5,7 @@
  *
  * Copyright (C) 2005-2006  NTT DATA CORPORATION
  *
- * Version: 1.3.1     2006/12/08
+ * Version: 1.3.1     2007/01/07
  *
  */
 #include <stdio.h>
@@ -429,18 +429,21 @@ static void ReadDomainPolicy(void) {
 			NormalizeLine(buffer);
 			if (IsDomainDef(buffer)) {
 				index = FindOrAssignNewDomain(buffer);
-			} else if (index >= 0 && (atoi(buffer) & 1) == 1 && (cp = strchr(buffer, ' ')) != NULL &&
-					   IsCorrectPath(cp + 1, 0) && !strendswith(cp + 1, "/") && IsInitializer(cp + 1)) {
-				int virtual_index;
-				static char buffer2[MAXBUFSIZE];
-				memset(buffer2, 0, sizeof(buffer2));
-				snprintf(buffer2, sizeof(buffer2) - 1, "%s %s", domain_list[index].domainname, cp + 1);
-				NormalizeLine(buffer2);
-				if ((virtual_index = FindOrAssignNewDomain(buffer2)) == EOF) {
-					fprintf(stderr, "ERROR: Can't create domain for '%s'.\n", buffer2);
-					exit(127);
+			} else if (index >= 0 && (atoi(buffer) & 1) == 1 && (cp = strchr(buffer, ' ')) != NULL) {
+				char *cp2 = strstr(cp + 1, " if ");
+				if (cp2) *cp2 = '\0';
+				if (IsCorrectPath(cp + 1, 0) && !strendswith(cp + 1, "/") && IsInitializer(cp + 1)) {
+					int virtual_index;
+					static char buffer2[MAXBUFSIZE];
+					memset(buffer2, 0, sizeof(buffer2));
+					snprintf(buffer2, sizeof(buffer2) - 1, "%s %s", domain_list[index].domainname, cp + 1);
+					NormalizeLine(buffer2);
+					if ((virtual_index = FindOrAssignNewDomain(buffer2)) == EOF) {
+						fprintf(stderr, "ERROR: Can't create domain for '%s'.\n", buffer2);
+						exit(127);
+					}
+					domain_list[virtual_index].is_virtual = 1;
 				}
-				domain_list[virtual_index].is_virtual = 1;
 			}
 		}
 		put();
